@@ -159,8 +159,10 @@ void SPIRVToLLVMDbgTran::transDbgInfo(const SPIRVValue *SV, Value *V) {
     return;
 
   if (Instruction *I = dyn_cast<Instruction>(V)) {
-    const SPIRVInstruction *SI = static_cast<const SPIRVInstruction *>(SV);
-    I->setDebugLoc(transDebugScope(SI));
+    if (SV->isInst()) {
+      const SPIRVInstruction *SI = static_cast<const SPIRVInstruction *>(SV);
+      I->setDebugLoc(transDebugScope(SI));
+    }
   }
 }
 
@@ -1572,24 +1574,19 @@ SPIRVToLLVMDbgTran::transDebugIntrinsic(const SPIRVExtInst *DebugInst,
   case SPIRVDebug::Declare: {
     using namespace SPIRVDebug::Operand::DebugDeclare;
     auto LocalVar = GetLocalVar(Ops[DebugLocalVarIdx]);
+    DebugLoc Loc = transDebugScope(DebugInst);
+    if (!Loc)
+      Loc = LocalVar.second;
     DIBuilder &DIB = getDIBuilder(DebugInst);
     if (getDbgInst<SPIRVDebug::DebugInfoNone>(Ops[VariableIdx])) {
-      // If we don't have the variable(e.g. alloca might be promoted by mem2reg)
-      // we should generate the following IR:
-      // call void @llvm.dbg.declare(metadata !4, metadata !14, metadata !5)
-      // !4 = !{}
-      // DIBuilder::insertDeclare doesn't allow to pass nullptr for the Storage
-      // parameter. To work around this limitation we create a dummy temp
-      // alloca, use it to create llvm.dbg.declare, and then remove the alloca.
-      auto *AI = new AllocaInst(Type::getInt8Ty(M->getContext()), 0, "tmp", BB);
+      auto *Null =
+          ConstantPointerNull::get(PointerType::get(M->getContext(), 0));
       DbgInstPtr DbgDeclare = DIB.insertDeclare(
-          AI, LocalVar.first, GetExpression(Ops[ExpressionIdx]),
-          LocalVar.second, BB);
-      AI->eraseFromParent();
+          Null, LocalVar.first, GetExpression(Ops[ExpressionIdx]), Loc, BB);
       return DbgDeclare;
     }
     return DIB.insertDeclare(GetValue(Ops[VariableIdx]), LocalVar.first,
-                             GetExpression(Ops[ExpressionIdx]), LocalVar.second,
+                             GetExpression(Ops[ExpressionIdx]), Loc,
                              BB);
   }
   case SPIRVDebug::Value: {
@@ -1597,8 +1594,9 @@ SPIRVToLLVMDbgTran::transDebugIntrinsic(const SPIRVExtInst *DebugInst,
     auto LocalVar = GetLocalVar(Ops[DebugLocalVarIdx]);
     Value *Val = GetValue(Ops[ValueIdx]);
     DIExpression *Expr = GetExpression(Ops[ExpressionIdx]);
+    DebugLoc Loc = transDebugScope(DebugInst);
     DbgInstPtr DbgValIntr = getDIBuilder(DebugInst).insertDbgValueIntrinsic(
-        Val, LocalVar.first, Expr, LocalVar.second, BB);
+        Val, LocalVar.first, Expr, Loc, BB);
 
     std::vector<ValueAsMetadata *> MDs;
     for (size_t I = 0; I != Expr->getNumLocationOperands(); ++I) {
@@ -1606,13 +1604,8 @@ SPIRVToLLVMDbgTran::transDebugIntrinsic(const SPIRVExtInst *DebugInst,
     }
     if (!MDs.empty()) {
       DIArgList *AL = DIArgList::get(M->getContext(), MDs);
-      if (M->IsNewDbgInfoFormat) {
-        cast<DbgVariableRecord>(cast<DbgRecord *>(DbgValIntr))
-            ->setRawLocation(AL);
-      } else {
-        cast<DbgVariableIntrinsic>(cast<Instruction *>(DbgValIntr))
-            ->setRawLocation(AL);
-      }
+      cast<DbgVariableRecord>(cast<DbgRecord *>(DbgValIntr))
+          ->setRawLocation(AL);
     }
     return DbgValIntr;
   }
