@@ -40,7 +40,6 @@
 #ifndef SPIRV_LIBSPIRV_SPIRVENTRY_H
 #define SPIRV_LIBSPIRV_SPIRVENTRY_H
 
-#include "LLVMSPIRVOpts.h"
 #include "SPIRVEnum.h"
 #include "SPIRVError.h"
 #include "SPIRVIsValidEnum.h"
@@ -917,8 +916,6 @@ public:
     case CapabilityFunctionVariantsINTEL:
     case CapabilitySpecConditionalINTEL:
       return ExtensionID::SPV_INTEL_function_variants;
-    case internal::CapabilityBFloat16ArithmeticINTEL:
-      return ExtensionID::SPV_INTEL_bfloat16_arithmetic;
     default:
       return {};
     }
