@@ -341,7 +341,6 @@ _SPIRV_OP(UntypedInBoundsAccessChainKHR, 4420)
 _SPIRV_OP(UntypedPtrAccessChainKHR, 4423)
 _SPIRV_OP(UntypedInBoundsPtrAccessChainKHR, 4424)
 _SPIRV_OP(UntypedPrefetchKHR, 4426)
-_SPIRV_OP(FmaKHR, 4427)
 _SPIRV_OP(GroupNonUniformRotateKHR, 4431)
 _SPIRV_OP(SDotKHR, 4450)
 _SPIRV_OP(UDotKHR, 4451)
@@ -580,6 +579,7 @@ _SPIRV_OP(Subgroup2DBlockLoadTransposeINTEL, 6233)
 _SPIRV_OP(Subgroup2DBlockPrefetchINTEL, 6234)
 _SPIRV_OP(Subgroup2DBlockStoreINTEL, 6235)
 _SPIRV_OP(SubgroupMatrixMultiplyAccumulateINTEL, 6237)
+_SPIRV_OP(BitwiseFunctionINTEL, 6242)
 _SPIRV_OP(ConditionalExtensionINTEL, 6248)
 _SPIRV_OP(ConditionalEntryPointINTEL, 6249)
 _SPIRV_OP(ConditionalCapabilityINTEL, 6250)
@@ -587,7 +587,6 @@ _SPIRV_OP(SpecConstantTargetINTEL, 6251)
 _SPIRV_OP(SpecConstantArchitectureINTEL, 6252)
 _SPIRV_OP(SpecConstantCapabilitiesINTEL, 6253)
 _SPIRV_OP(ConditionalCopyObjectINTEL, 6254)
-_SPIRV_OP(BitwiseFunctionINTEL, 6242)
 _SPIRV_OP(GroupIMulKHR, 6401)
 _SPIRV_OP(GroupFMulKHR, 6402)
 _SPIRV_OP(GroupBitwiseAndKHR, 6403)
@@ -596,3 +595,4 @@ _SPIRV_OP(GroupBitwiseXorKHR, 6405)
 _SPIRV_OP(GroupLogicalAndKHR, 6406)
 _SPIRV_OP(GroupLogicalOrKHR, 6407)
 _SPIRV_OP(GroupLogicalXorKHR, 6408)
+_SPIRV_OP(RoundFToTF32INTEL, 6426)
